@@ -1,6 +1,5 @@
 import time
 from xml.etree.ElementTree import Element, SubElement
-from elifearticle import utils as eautils
 from elifetools import utils as etoolsutils
 from jatsgenerator import utils
 
@@ -165,14 +164,16 @@ def set_aff(
         aff.text = affiliation.text
         return
 
-    if institution_wrap:
+    if institution_wrap and (
+        affiliation.ror or affiliation.department or affiliation.institution
+    ):
         institution_parent_tag = SubElement(aff, "institution-wrap")
     else:
         institution_parent_tag = aff
 
     if affiliation.ror:
         institution_id = SubElement(institution_parent_tag, "institution-id")
-        institution_id.set("institution-id", "ror")
+        institution_id.set("institution-id-type", "ror")
         institution_id.text = affiliation.ror
 
     if contrib_type != "editor":
@@ -338,13 +339,28 @@ def set_license(parent, poa_article):
     ext_link.tail = poa_article.license.paragraph2
 
 
-def set_copyright(parent, poa_article):
-    # Count authors (non-editors)
-    non_editor = []
-    for contributor in poa_article.contributors:
-        if contributor.contrib_type != "editor":
-            non_editor.append(contributor)
+def set_copyright_tags(parent, copyright_year, copyright_holder):
+    "add copyright tags"
+    copyright_statement = "\u00a9 " + str(copyright_year) + ", " + copyright_holder
+    copyright_tag = SubElement(parent, "copyright-statement")
+    copyright_tag.text = copyright_statement
 
+    # copyright-year
+    copyright_year_tag = SubElement(parent, "copyright-year")
+    copyright_year_tag.text = str(copyright_year)
+
+    # copyright-holder
+    copyright_holder_tag = SubElement(parent, "copyright-holder")
+    copyright_holder_tag.text = copyright_holder
+
+
+def generate_copyright_holder(contributor_list):
+    "copyright holder string from Article editor contributors"
+    non_editor = []
+    for contributor in contributor_list:
+        if contributor.contrib_type != "editor" and contributor.surname:
+            non_editor.append(contributor)
+    # Count authors (non-editors)
     if len(non_editor) > 2:
         contributor = non_editor[0]
         copyright_holder = contributor.surname + " et al"
@@ -357,6 +373,12 @@ def set_copyright(parent, poa_article):
         copyright_holder = contributor.surname
     else:
         copyright_holder = ""
+    return copyright_holder
+
+
+def set_copyright(parent, poa_article):
+    "collect copyright data and set copyright tags"
+    copyright_holder = generate_copyright_holder(poa_article.contributors)
 
     # copyright-statement
     copyright_year = ""
@@ -367,17 +389,7 @@ def set_copyright(parent, poa_article):
     if date:
         copyright_year = date.date.tm_year
 
-    copyright_statement = "\u00a9 " + str(copyright_year) + ", " + copyright_holder
-    copyright_tag = SubElement(parent, "copyright-statement")
-    copyright_tag.text = copyright_statement
-
-    # copyright-year
-    copyright_year_tag = SubElement(parent, "copyright-year")
-    copyright_year_tag.text = str(copyright_year)
-
-    # copyright-holder
-    copyright_holder_tag = SubElement(parent, "copyright-holder")
-    copyright_holder_tag.text = copyright_holder
+    set_copyright_tags(parent, copyright_year, copyright_holder)
 
 
 def set_permissions(parent, poa_article):
@@ -464,26 +476,40 @@ def do_subject_heading(poa_article):
     return False
 
 
+def set_subject(parent, subj_group_type, text):
+    "add subject tag to added subj-group tag"
+    subj_group = SubElement(parent, "subj-group")
+    subj_group.set("subj-group-type", subj_group_type)
+    subject_tag = SubElement(subj_group, "subject")
+    subject_tag.text = text
+
+
+def set_display_channel(parent, text):
+    "add tag subj-group subj-group-type display-channel"
+    set_subject(parent, "display-channel", text)
+
+
+def set_major_subject_area(parent, text):
+    "add tag subj-group subj-group-type heading"
+    set_subject(parent, "heading", text)
+
+
 def set_article_categories(parent, poa_article):
     # article-categories
     if do_article_categories(poa_article):
-        article_categories = SubElement(parent, "article-categories")
+        article_categories_tag = SubElement(parent, "article-categories")
 
         if do_display_channel(poa_article):
             # subj-group subj-group-type="display-channel"
-            subj_group = SubElement(article_categories, "subj-group")
-            subj_group.set("subj-group-type", "display-channel")
-            subject = SubElement(subj_group, "subject")
-            subject.text = poa_article.get_display_channel()
+            set_display_channel(
+                article_categories_tag, poa_article.get_display_channel()
+            )
 
         if do_subject_heading(poa_article):
             for article_category in poa_article.article_categories:
                 # subj-group subj-group-type="heading"
                 if article_category and article_category.rstrip().lstrip() != "":
-                    subj_group = SubElement(article_categories, "subj-group")
-                    subj_group.set("subj-group-type", "heading")
-                    subject = SubElement(subj_group, "subject")
-                    subject.text = article_category
+                    set_major_subject_area(article_categories_tag, article_category)
 
 
 def set_kwd_group_research_organism(parent, poa_article):
@@ -542,7 +568,7 @@ def set_funding_source(parent, institution_id, institution_name):
         institution_id_tag.text = "http://dx.doi.org/10.13039/" + institution_id
     if institution_name:
         institution_tag = SubElement(institution_wrap, "institution")
-        institution_tag.text = eautils.entity_to_unicode(institution_name)
+        institution_tag.text = etoolsutils.entity_to_unicode(institution_name)
 
 
 def set_principal_award_recipients(parent, award):
