@@ -5,6 +5,7 @@ from xml.etree.ElementTree import Element
 from elifearticle.article import (
     Affiliation,
     Article,
+    ArticleDate,
     ContentBlock,
     Contributor,
     Event,
@@ -165,6 +166,15 @@ class TestSetAff(unittest.TestCase):
         expected = b"<root><aff /></root>"
         self.assertEqual(xml_string, expected)
 
+    def test_set_aff_omit_institution_wrap(self):
+        "test an empty institution-wrap tag is not added when there is no data"
+        root = Element("root")
+        contrib_type = "author"
+        build.set_aff(root, Affiliation(), contrib_type, institution_wrap=True)
+        xml_string = ElementTree.tostring(root, encoding="utf-8")
+        expected = b"<root><aff /></root>"
+        self.assertEqual(xml_string, expected)
+
     def test_set_aff_default(self):
         "default, older, style with some comma separated tags"
         root = Element("root")
@@ -175,7 +185,7 @@ class TestSetAff(unittest.TestCase):
         expected = (
             b"<root>"
             b'<aff id="1">'
-            b'<institution-id institution-id="ror">ror</institution-id>'
+            b'<institution-id institution-id-type="ror">ror</institution-id>'
             b'<institution content-type="dept">Department</institution>, '
             b"<institution>Institution</institution>, "
             b"<addr-line>"
@@ -198,7 +208,7 @@ class TestSetAff(unittest.TestCase):
         xml_string = ElementTree.tostring(root, encoding="utf-8")
         expected = (
             b"<root>"
-            b'<aff id="1"><institution-id institution-id="ror">ror</institution-id>'
+            b'<aff id="1"><institution-id institution-id-type="ror">ror</institution-id>'
             b"<institution>Institution</institution>, "
             b"<addr-line>"
             b'<named-content content-type="city">City</named-content>'
@@ -226,7 +236,7 @@ class TestSetAff(unittest.TestCase):
             b"<root>"
             b'<aff id="1">'
             b"<institution-wrap>"
-            b'<institution-id institution-id="ror">ror</institution-id>'
+            b'<institution-id institution-id-type="ror">ror</institution-id>'
             b'<institution content-type="dept">Department</institution>'
             b"<institution>Institution</institution>"
             b"</institution-wrap>"
@@ -346,6 +356,97 @@ class TestSetSubArticle(unittest.TestCase):
         self.assertEqual(xml_string, expected)
 
 
+class TestSetCopyrightTags(unittest.TestCase):
+    "tests for set_copyright_tags()"
+
+    def test_set_copyright_tags(self):
+        "test setting copyright XML tags"
+        parent = Element("root")
+        copyright_year = "2024"
+        copyright_holder = "Surname et al"
+        expected = (
+            b"<root>"
+            b"<copyright-statement>\xc2\xa9 2024, Surname et al</copyright-statement>"
+            b"<copyright-year>2024</copyright-year>"
+            b"<copyright-holder>Surname et al</copyright-holder>"
+            b"</root>"
+        )
+        # invoke
+        build.set_copyright_tags(parent, copyright_year, copyright_holder)
+        # assert
+        xml_string = ElementTree.tostring(parent, encoding="utf-8")
+        self.assertEqual(xml_string, expected)
+
+
+class TestGenerateCopyrightHolder(unittest.TestCase):
+    "tests for generate_copyright_holder()"
+
+    def test_one_author(self):
+        "test generating copyright holder string for one author"
+        contributor_list = [Contributor("author", "Surname", "Given")]
+        expected = "Surname"
+        # invoke
+        result = build.generate_copyright_holder(contributor_list)
+        # assert
+        self.assertEqual(result, expected)
+
+    def test_two_authors(self):
+        "test generating copyright holder string for two authors"
+        contributor_list = [
+            Contributor("author", "Surname", "Given"),
+            Contributor("author", "Surname2", "Given2"),
+        ]
+        expected = "Surname & Surname2"
+        # invoke
+        result = build.generate_copyright_holder(contributor_list)
+        # assert
+        self.assertEqual(result, expected)
+
+    def test_multiple_authors(self):
+        "test generating copyright holder string for more than two authors"
+        contributor_list = [
+            Contributor("author", "Surname", "Given"),
+            Contributor("author", "Surname2", "Given2"),
+            Contributor("author", "Surname3", "Given3"),
+        ]
+        expected = "Surname et al"
+        # invoke
+        result = build.generate_copyright_holder(contributor_list)
+        # assert
+        self.assertEqual(result, expected)
+
+
+class TestSetCopyright(unittest.TestCase):
+    "tests for set_copyright()"
+
+    def test_set_copyright(self):
+        "test building copyright tag"
+        root = Element("root")
+        article = Article("10.7554/eLife.00666", "Title")
+        # test a contributor with no surname
+        contributor_1 = Contributor("author", None, None, collab="Collab Name")
+        article.add_contributor(contributor_1)
+        contributor_2 = Contributor("author", "Surname", "Given")
+        article.add_contributor(contributor_2)
+        license_date = time.strptime("2037-11-13", "%Y-%m-%d")
+        date_object = ArticleDate("license", license_date)
+        article.dates["license"] = date_object
+        expected = (
+            b"<root>"
+            b"<copyright-statement>"
+            b"\xc2\xa9 2037, Surname"
+            b"</copyright-statement>"
+            b"<copyright-year>2037</copyright-year>"
+            b"<copyright-holder>Surname</copyright-holder>"
+            b"</root>"
+        )
+        # invoke
+        build.set_copyright(root, article)
+        # assert
+        xml_string = ElementTree.tostring(root, encoding="utf-8")
+        self.assertEqual(xml_string, expected)
+
+
 class TestSetAbstract(unittest.TestCase):
     def test_set_abstract(self):
         "test setting an abstract"
